@@ -3,17 +3,14 @@ from .iam_actions import (
     action_login, action_logout, action_token
 )
 from .iam_common import (
-    IamServer
+    IamServer, IamParam
+)
+from .iam_pomes import (
+    iam_setup, iam_get_env_parameters, iam_get_token
 )
 from .iam_services import (
      jwt_required, logger_register
 )
-from .jusbr_pomes import (
-    jusbr_setup, jusbr_get_token
-)
-from .keycloak_pomes import (
-    keycloak_setup, keycloak_get_token
-)
 from .provider_pomes import (
     provider_register, provider_get_token
 )
@@ -26,13 +23,11 @@ __all__ = [
     "action_callback", "action_exchange",
     "action_login", "action_logout", "action_token",
     # iam_commons
-    "IamServer",
+    "IamServer", "IamParam",
+    # iam_pomes
+    "iam_setup", "iam_get_env_parameters", "iam_get_token",
     # iam_services
     "jwt_required", "logger_register",
-    # jusbr_pomes
-    "jusbr_setup", "jusbr_get_token",
-    # keycloak_pomes
-    "keycloak_setup", "keycloak_get_token",
     # provider_pomes
     "provider_register", "provider_get_token",
     # token_pomes
