@@ -59,7 +59,7 @@ def action_login(iam_server: IamServer,
                                               errors=errors,
                                               logger=logger)
             if not errors:
-                user_data[UserParam.LOGIN_EXPIRATION] = int(datetime.now(tz=TZ_LOCAL).timestamp()) + timeout \
+                user_data[UserParam.LOGIN_EXPIRATION] = (int(datetime.now(tz=TZ_LOCAL).timestamp()) + timeout) \
                     if timeout else None
                 redirect_uri: str = args.get(UserParam.REDIRECT_URI)
                 user_data[UserParam.REDIRECT_URI] = redirect_uri
@@ -138,6 +138,7 @@ def action_token(iam_server: IamServer,
                                                        user_id=user_id,
                                                        errors=errors,
                                                        logger=logger)
+            # retrieve the stored access token
             token: str = user_data[UserParam.ACCESS_TOKEN] if user_data else None
             if token:
                 access_expiration: int = user_data.get(UserParam.ACCESS_EXPIRATION)
@@ -148,7 +149,7 @@ def action_token(iam_server: IamServer,
                     # access token has expired
                     refresh_token: str = user_data[UserParam.REFRESH_TOKEN]
                     if refresh_token:
-                        refresh_expiration = user_data[UserParam.REFRESH_EXPIRATION]
+                        refresh_expiration: int = user_data[UserParam.REFRESH_EXPIRATION]
                         if now < refresh_expiration:
                             header_data: dict[str, str] = {
                                 "Content-Type": "application/json"
@@ -242,7 +243,7 @@ def action_callback(iam_server: IamServer,
                 users.pop(oauth_state)
                 code: str = args.get("code")
                 header_data: dict[str, str] = {
-                    "Content-Type": "application/json"
+                    "Content-Type": "application/x-www-form-urlencoded"
                 }
                 body_data: dict[str, Any] = {
                     "grant_type": "authorization_code",
@@ -454,27 +455,36 @@ def __get_administrative_token(iam_server: IamServer,
     registry: dict[str, Any] = _get_iam_registry(iam_server=iam_server,
                                                  errors=errors,
                                                  logger=logger)
-    if registry and registry[IamParam.ADMIN_ID] and registry[IamParam.ADMIN_SECRET]:
-        header_data: dict[str, str] = {
-            "Content-Type": "application/json"
-        }
-        body_data: dict[str, str] = {
-            "grant-type": "password",
-            "username": registry[IamParam.ADMIN_ID],
-            "password": registry[IamParam.ADMIN_SECRET],
-            "client_id": registry[IamParam.CLIENT_ID]
-        }
-        token_data: dict[str, Any] = __post_for_token(iam_server=iam_server,
-                                                      header_data=header_data,
-                                                      body_data=body_data,
-                                                      errors=errors,
-                                                      logger=logger)
-        if token_data:
-            # obtain the token
-            result = token_data["access_token"]
-    else:
-        msg: str = (f"To obtain token with administrative rights from '{iam_server}', "
-                    f"the credentials for the realm administrator must be provided at setup time")
+    if registry:
+        if registry[IamParam.ADMIN_ID] and registry[IamParam.ADMIN_SECRET]:
+            header_data: dict[str, str] = {
+                "Content-Type": "application/x-www-form-urlencoded"
+            }
+            body_data: dict[str, str] = {
+                "grant-type": "password",
+                "username": registry[IamParam.ADMIN_ID],
+                "password": registry[IamParam.ADMIN_SECRET],
+                "client_id": registry[IamParam.CLIENT_ID]
+            }
+            token_data: dict[str, Any] = __post_for_token(iam_server=iam_server,
+                                                          header_data=header_data,
+                                                          body_data=body_data,
+                                                          errors=errors,
+                                                          logger=logger)
+            if token_data:
+                # obtain the token
+                result = token_data["access_token"]
+
+        elif logger or isinstance(errors, list):
+            msg: str = ("Credentials for administrator of realm "
+                        f"'{registry[IamParam.CLIENT_REALM]}' of '{iam_server}' not provided")
+            if logger:
+                logger.error(msg=msg)
+            if isinstance(errors, list):
+                errors.append(msg)
+
+    elif logger or isinstance(errors, list):
+        msg: str = f"Unknown IAM server {iam_server}"
         if logger:
             logger.error(msg=msg)
         if isinstance(errors, list):
@@ -573,7 +583,7 @@ def __get_for_data(url: str,
                 logger.debug(msg=f"GET success, {json.dumps(obj=result,
                                                             ensure_ascii=False)}")
         else:
-            # request resulted in error
+            # request failed, report the problem
             msg: str = f"GET failure, status {response.status_code}, reason {response.reason}"
             if hasattr(response, "content") and response.content:
                 msg += f", content '{response.content}'"
@@ -615,7 +625,7 @@ def __post_data(url: str,
                                                    headers=header_data,
                                                    data=body_data)
         if response.status_code >= 400:
-            # request resulted in error
+            # request failed, report the problem
             msg = f"POST failure, status {response.status_code}, reason {response.reason}"
             if hasattr(response, "content") and response.content:
                 msg += f", content '{response.content}'"
@@ -735,7 +745,7 @@ def __post_for_token(iam_server: IamServer,
                         logger.debug(msg=f"POST success, {json.dumps(obj=result,
                                                                      ensure_ascii=False)}")
                 else:
-                    # request resulted in error
+                    # request failed, report the problem
                     err_msg = f"POST failure, status {response.status_code}, reason {response.reason}"
                     if hasattr(response, "content") and response.content:
                         err_msg += f", content '{response.content}'"
